Index: src/spaces.cc |
diff --git a/src/spaces.cc b/src/spaces.cc |
index e7cb8ccf85254003af635e44c2fe81d582e2b926..6f67066b9980d911c703f27b64b4b4a970fc6556 100644 |
--- a/src/spaces.cc |
+++ b/src/spaces.cc |
@@ -3062,10 +3062,12 @@ void LargeObjectSpace::Verify() { |
// We have only code, sequential strings, external strings |
// (sequential strings that have been morphed into external |
// strings), fixed arrays, and byte arrays in large object space. |
CHECK(object->IsCode() || object->IsSeqString() || |
- object->IsExternalString() || object->IsFixedArray() || |
- object->IsFixedDoubleArray() || object->IsByteArray()); |
+ object->IsExternalString() || object->IsFixedArray() || |
+ object->IsFixedDoubleArray() || object->IsByteArray() || |
+ object->IsConstantPoolArray()); |
// The object itself should look OK. |
object->ObjectVerify(); |
@@ -3062,10 +3062,12 @@ void LargeObjectSpace::Verify() { |
// We have only code, sequential strings, external strings |
// (sequential strings that have been morphed into external |
- // strings), fixed arrays, and byte arrays in large object space. |
+ // strings), fixed arrays, byte arrays, and constant pool arrays in the |
+ // large object space. |
CHECK(object->IsCode() || object->IsSeqString() || |